##############################################
# R script for illustrating the analysis
# of diffusion processes with RSiena.
# version of 8 February 2017
# written by Christian Steglich
##############################################

# load RSiena commands:
library(RSiena)
packageVersion("RSiena")

# set working directory to where the data are:
setwd("<put your directory name here>")
list.files()

# read the datasets:
load("Glasgow-friendship.RData")
load("Glasgow-substances.RData")
load("Glasgow-demographic.RData")
ls()

# recode valued friendship data: 
friendship.1[friendship.1==2] <- 1
friendship.2[friendship.2==2] <- 1
friendship.3[friendship.3==2] <- 1

# check cannabis use:
table(cannabis[,1],cannabis[,2])
table(cannabis[,2],cannabis[,3])
# interpret this with the help of the response categories
# in the questionnaire

# For illustration, we focus on the period T2->T3 which shows
# more cannabis dynamics

# transition "never" to "ever":
table(cannabis[,2]>1,cannabis[,3]>1)
# inconsistent response patterns!

# "solve" inconsistency be recoding to missing:
(inco <- which(cannabis[,2]>1 & cannabis[,3]==1))
cannabis[inco,2:3] <- NA
 
# define data:
thedata <- sienaDataCreate(
	friendship = sienaDependent(
		array(c(friendship.2,friendship.3),dim=c(160,160,2))
	),
	hash = sienaDependent(1*(cannabis[,2:3]>1),type='behavior'),
	sexF = coCovar(sex.F)
)
thedata

# get effects table and specify model:
theeffects <- getEffects(thedata)
effectsDocumentation(theeffects)
theeffects <- includeEffects(theeffects,transTrip,transRecTrip)
	name="friendship")
theeffects <- includeEffects(theeffects,sameX,
	name="friendship",interaction1="sexF")
theeffects <- includeEffects(theeffects,egoX,altX,egoXaltX,
	name="friendship",interaction1="hash")
theeffects <- includeEffects(theeffects,avExposure,
	name="hash",type="rate",interaction1="friendship")
theeffects <- includeEffects(theeffects,RateX,
	name="hash",type="rate",interaction1="sexF")
theeffects

# create estimation options object:
theoptions <- sienaAlgorithmCreate(useStdInits=FALSE,
	projname='theresults',MaxDegree=c(friendship=6),seed=123)

# estimate model:
theresults <- siena07(theoptions,data=thedata,effects=theeffects)
theresults

# check out RSiena diffusion publications with Charlotte Greenan
# and / or Kayla de la Haye!
